from outpunch import ClientConfig


def test_config_defaults():
    c = ClientConfig(server_url="ws://x", secret="s", service="svc")
    assert c.forward_to == "http://localhost:8080"
    assert c.reconnect_delay == 5.0
    assert c.request_timeout == 25.0


def test_config_custom_values():
    c = ClientConfig(
        server_url="wss://example.com/ws",
        secret="my-secret",
        service="my-app",
        forward_to="http://localhost:9000",
        reconnect_delay=10.0,
        request_timeout=30.0,
    )
    assert c.server_url == "wss://example.com/ws"
    assert c.secret == "my-secret"
    assert c.service == "my-app"
    assert c.forward_to == "http://localhost:9000"
    assert c.reconnect_delay == 10.0
    assert c.request_timeout == 30.0


def test_config_repr():
    c = ClientConfig(server_url="ws://x", secret="s", service="svc")
    r = repr(c)
    assert "ws://x" in r
    assert "svc" in r
    assert "http://localhost:8080" in r


def test_config_fields_mutable():
    c = ClientConfig(server_url="ws://x", secret="s", service="svc")
    c.forward_to = "http://localhost:3000"
    assert c.forward_to == "http://localhost:3000"
    c.reconnect_delay = 15.0
    assert c.reconnect_delay == 15.0



import pytest

from outpunch import ClientConfig, run_connection


@pytest.mark.asyncio
async def test_run_connection_fails_when_server_unreachable():
    config = ClientConfig(
        server_url="ws://127.0.0.1:1/ws",
        secret="secret",
        service="svc",
        forward_to="http://localhost:8080",
    )
    with pytest.raises(RuntimeError):
        await run_connection(config)



from typing import Any, Coroutine

class ClientConfig:
    server_url: str
    secret: str
    service: str
    forward_to: str
    reconnect_delay: float
    request_timeout: float

    def __init__(
        self,
        server_url: str,
        secret: str,
        service: str,
        forward_to: str = "http://localhost:8080",
        reconnect_delay: float = 5.0,
        request_timeout: float = 25.0,
    ) -> None: ...
    def __repr__(self) -> str: ...

def run(config: ClientConfig) -> None: ...
def run_connection(config: ClientConfig) -> Coroutine[Any, Any, None]: ...
